import artifacts from "./artifacts";
import ArtifactStore from "./artifactStore";
import  GitlabRepository from "./gitlabServer";
import AppView from "./view";

function setSelectedBranch(view, branchName) {
    let branchOption = view.querySelector(`option[value="${branchName}"]`);
    branchOption.setAttribute("selected", "true");      
    return branchOption;
  }


function findGetParameter(parameterName, defaultValue=null) { 
    let result = null;
    let tmp = [];
    location.search
      .substr(1)
      .split("&")
      .forEach(function (item) {
        tmp = item.split("=");
        if (tmp[0] === parameterName) result = decodeURIComponent(tmp[1]);
    });
    
    if(!result) return defaultValue;
    return result;
  }




async function pageRootGeometry() {
    let artStore = new ArtifactStore(artifacts);
    let imagesDiv = document.getElementById("mainField");
    
    // What branch we want?       
    let branch = findGetParameter("br"); 
    if(!branch) branch = "master"; 

    let fileUrl = 'https://eicweb.phy.anl.gov/api/v4/projects/473/jobs/artifacts/master/raw/geo/detector_geo.root'
    let options = 'clipxyz;transp30;zoom100;ROTY0;ROTZ0;trz100;trr0;ctrl;all'
    let viewerUrl = `geo.htm?browser&file=${fileUrl}?job=report&item=default;1&opt=${options}&`;
    console.log(viewerUrl);
    //file=https://eicweb.phy.anl.gov/api/v4/projects/473/jobs/artifacts/master/raw/geo/detector_geo.root
    renderGeoViewer(imagesDiv, viewerUrl);
}

async function showArtifactsByPipeline(pipeline ,gitlabServer, view, artStore) {
    if(!pipeline) {
        view.showWarning(`Pipeline is not found on server`);
        return;
    }

    view.renderPipeline(pipeline);    
          
    // pull job out of the server
    let reportJob = await gitlabServer.getJob(pipeline.id, "report");

    if (reportJob === null) {
        view.renderWarning(`Error loading job "report" for pipeline ${pipeline.id}`);
        return;
    };

    view.renderJob(reportJob);

    // Show artifacts knowing jobId
    let imageArts = artStore.getImageArtifacts();
    imageArts.forEach(art=>{
        let imgRef = `https://eicweb.phy.anl.gov/EIC/detectors/athena/-/jobs/${reportJob.id}/artifacts/raw/${art.path}`
        let pdfRef = `https://eicweb.phy.anl.gov/EIC/detectors/athena/-/jobs/${reportJob.id}/artifacts/raw/${art.imagePdf}`
        // TODO better image name than art.path! Like single file name
        view.renderImage(art, imgRef, pdfRef);
        
    });
}

async function pageArtifactsByBranch() {

    // Connect to artifacts and repository
    let artStore = new ArtifactStore(artifacts);
    let gitlabServer = new GitlabRepository("https://eicweb.phy.anl.gov/api/v4", 473);
    let view = new AppView();


    // Load branches 
    let branches = await gitlabServer.getBranches();
    // Render branches
    view.renderBranches(branches);     // Вывести все ветки
    
    $( document ).ready(function() {
        console.log("Enabling select2")
        $('#branch').select2();
    });   
    // let imagesDiv = document.getElementById("images-id"); //где используем?
    
    // What branch we want?       
    let branch = findGetParameter("br"); 
    if(!branch) branch = "master"; 

    let branchSelect = document.querySelector(`#branch`);

    setSelectedBranch(branchSelect, branch);  // Выбрать ту, которую мы смотрим

    let pipeline = await gitlabServer.getLatestPipelineForBranch(branch); 
    
    showArtifactsByPipeline(pipeline, gitlabServer, view, artStore);
}

async function pageArtifactsByPipelineId() {

        // Connect to artifacts and repository
        let artStore = new ArtifactStore(artifacts);
        let gitlabServer = new GitlabRepository("https://eicweb.phy.anl.gov/api/v4", 473);
        let view = new AppView();

        // Requiested Pipeline ID
        let reqPlId = findGetParameter("pid", "0");
        console.log(reqPlId);

        // Show pipeline
        let pipeline = await gitlabServer.getPipelineById(reqPlId);

        showArtifactsByPipeline(pipeline, gitlabServer, view, artStore); 
}

async function pageTest() {

    let imagesDiv = document.getElementById("images-id"); 
    let url = "https://www.digitalphotomentor.com/photography/2018/05/famous-photographs-Dorothea.Lange_.1936-migrant-mother-750x975.jpg"
    renderImage(imagesDiv, "Mother", "1936 Migrant mother", url, url);
}


window.onload = function() {
    const operation = findGetParameter("op", "index");
    let pageGenerator = pageArtifactsByBranch;

    switch (operation) {
        case 'geo':
            pageGenerator = pageRootGeometry;
            break;
        case 'pl':
            pageGenerator = pageArtifactsByPipelineId;
            break;
        case 'test':
            pageGenerator = pageTest;
            break;
    };

    pageGenerator().then(()=>{
        console.log("Done page generation!");
    })
}