/**
 * Application view manipulation
 *  
 */
class AppView {
    constructor() {
        // artifacts container
        this.cntDiv = document.getElementById("main-content");
        this.msgDiv = document.getElementById("messages");
        this.plDiv = document.getElementById("pipeline");
        this.jobDiv = document.getElementById("job");
        this.branchesDiv = document.getElementById("branches");
        this.imagesDiv = document.getElementById("images");
        this.statusDiv = document.getElementById("status");

    }


    renderBranches(branches) {
        let options = `<option value="master">master</option>`;

        branches.forEach(branch=>{
            options +=`<option value="${branch.name}">${branch.name}</option>`;
        })

        this.branchesDiv.innerHTML = `
            <div class="row mb-4">
            <form id="branchesForm">
                <div class="col-6 flex-row" style="display: flex;">
                    <select id="branch" name="br" class="form-select" aria-label=".form-select-lg example">
                        ${options}
                    </select>
                <button input class="btn btn-primary" type="submit" value="Submit" style="margin-left: 1em;">Submit</button>
                </div>
            </form>
            </div>
        `;
    }


    renderGeoViewer(fileUrl) {    
        this.cntDiv.innerHTML = `<iframe src="${fileUrl}" frameborder="0" onload="calcHeight(this)" style="background: #000;border: none;width: 100%;height: 100%;" height="100%" width="100%"></iframe>`;
    }


    renderImage(art, imgRef, pdfRef) {
        let xhr = new XMLHttpRequest();
        xhr.open('GET', imgRef);
        xhr.responseType = "blob";
        xhr.onload = () => {
            if (xhr.status == 200) { 
                this.imagesDiv.innerHTML +=`
                <div class="col">
                    <div class="card shadow-sm">
                        <svg class="bd-placeholder-img card-img-top" width="100%" height="225" role="img" focusable="false">
                            <image x="0" y="0" width="100%" height="100%" href='${xhr.responseURL}'/>
                        </svg>
                        <div class="container">
                            <div class="row row-cols-auto">
                                <div class="col"><h5><small>${art.path}</small></h5></div>
                                <div class="col"><button class="button btn btn-link"><a href='${pdfRef}' target="_blank">pdf</a></button></div>
                            </div>
                            <p class="card-text">${art.desc !== undefined ? `${art.desc}`: ""}</p>
                        </div>      
                    </div>
                </div>`;
            };
        };
        xhr.send();
        
    }


    renderPipeline(pipeline) {
        this.plDiv.innerHTML += `
        <div>
            Pipeline <a href="${pipeline.web_url}" target="_blank">${pipeline.id}</a> status: ${pipeline.status}
        </div>
        `;
    }

    renderJob(job) {
        this.jobDiv.innerHTML += `
        <div>
        Job <a href="${job.web_url}" target="_blank">${job.name}</a> status: ${job.status} arts expire at: ${job.artifacts_expire_at}
        </div>
        <div class="tr"></div>
        `;
        
    }

    renderWarning(text) {
        
    }

    renderError(text) {
        this.msgDiv.innerHTML += `
            <div class="alert alert-error d-flex align-items-center" role="alert">
                <svg class="bi flex-shrink-0 me-2" width="24" height="24" role="img" aria-label="Error:"><use xlink:href="#exclamation-triangle-fill"/></svg>
                <div>${text}</div>
            </div>`;
    }


    showWarning(text) {
        this.msgDiv.innerHTML += `
            <div class="alert alert-warning d-flex align-items-center" role="alert">
                <svg class="bi flex-shrink-0 me-2" width="24" height="24" role="img" aria-label="Warning:"><use xlink:href="#exclamation-triangle-fill"/></svg>
                <div>${text}</div>
            </div>`;
    }
}

export default AppView;